@@ -1,6 +1,6 @@
 /****************************************************************************
  **
- ** $Id: cvsconfig.h,v 1.49 2004/05/07 18:39:36 riemer Exp $
+ ** $Id: cvsconfig.h,v 1.56 2005/01/10 17:19:08 frank Exp $
  **
  ** Copyright (C) 2001-2004 Tilo Riemer <riemer@lincvs.org>,
  **                         Frank Hemer <frank@hemer.org>,
@@ -126,7 +126,6 @@ class CvsConfig
    static const char ViewFileList[];
    static const char ScanOnTheFly[];
    static const char ScanNonCvs[];
-   static const char AskForQuit[];
    static const char CvsIgnoreFiles[];
    static const char UseExternalDiff[];
    static const char ExtDiffProgram[];
@@ -136,7 +135,9 @@ class CvsConfig
    static const char UseStandardDialogs[];
    static const char DateTimeOrder[];
    static const char DateTimeFormat[];
-
+   static const char Use0AsParent[];
+   static const char TopLevelWidget[];
+   
    static const char GeomX[];
    static const char GeomY[];
    static const char GeomWidth[];
@@ -226,7 +227,7 @@ class CvsConfig
    static const char defViewFileList[];
 
       
-public:
+ public:
    CvsConfig();
    ~CvsConfig();
 
@@ -242,12 +243,12 @@ public:
    }
    Debug::LogLevel logLevel() {
       switch (m_pSettings->readNumEntry(LogLevel, 0)) {
-      case 0:  return Debug::LL_LIKE_A_FISH;
-      case 1:  return Debug::LL_THE_OLD_MAN_AND_THE_SEA;
-      case 2:  return Debug::LL_INFO;
-      case 3:  return Debug::LL_DEBUG;
-      case 4:  return Debug::LL_GOSSIP_MONGER;
-      default: return Debug::LL_LIKE_A_FISH;
+	 case 0:  return Debug::LL_LIKE_A_FISH;
+	 case 1:  return Debug::LL_THE_OLD_MAN_AND_THE_SEA;
+	 case 2:  return Debug::LL_INFO;
+	 case 3:  return Debug::LL_DEBUG;
+	 case 4:  return Debug::LL_GOSSIP_MONGER;
+	 default: return Debug::LL_LIKE_A_FISH;
       }
    }
    bool setLogLevel(int level) {
@@ -353,16 +354,16 @@ public:
       m_pSettings->writeEntry(RwPermission, permission);
    }
    bool getShowVirtualInFiletab() {
-     return m_pSettings->readBoolEntry(VirtualInFiletab, true);
+      return m_pSettings->readBoolEntry(VirtualInFiletab, true);
    }
    void setShowVirtualInFiletab(bool state) {
-     m_pSettings->writeEntry(VirtualInFiletab, state);
+      m_pSettings->writeEntry(VirtualInFiletab, state);
    }
    int getDiffPrecision() {
-     return m_pSettings->readNumEntry(DiffPrecision,2);
+      return m_pSettings->readNumEntry(DiffPrecision,2);
    }
    void setDiffPrecision(int val) {
-     m_pSettings->writeEntry(DiffPrecision,val);
+      m_pSettings->writeEntry(DiffPrecision,val);
    }
    bool getUnifiedDiffOutput() {
       return m_pSettings->readBoolEntry(UnifiedDiffOutput, true);
@@ -471,20 +472,20 @@ public:
       m_pSettings->writeEntry(KeyboarsShortcuts,shortcuts);
    }
    QStringList getOpenFileList() {
-     QStringList list = m_pSettings->readListEntry(OpenFileList);
-     if (list.count() == 0) list.append(defOpenFileList);
-     return list;
+      QStringList list = m_pSettings->readListEntry(OpenFileList);
+      if (list.count() == 0) list.append(defOpenFileList);
+      return list;
    }
    void setOpenFileList(QStringList list) {
-     m_pSettings->writeEntry(OpenFileList,list);
+      m_pSettings->writeEntry(OpenFileList,list);
    }
    QStringList getViewFileList() {
-     QStringList list = m_pSettings->readListEntry(ViewFileList);
-     if (list.count() == 0) list.append(defViewFileList);
-     return list;
+      QStringList list = m_pSettings->readListEntry(ViewFileList);
+      if (list.count() == 0) list.append(defViewFileList);
+      return list;
    }
    void setViewFileList(QStringList list) {
-     m_pSettings->writeEntry(ViewFileList,list);
+      m_pSettings->writeEntry(ViewFileList,list);
    }
    bool getOnTheFlyScanning() {
       return m_pSettings->readBoolEntry(ScanOnTheFly, false);
@@ -498,12 +499,6 @@ public:
    void setScanNonCvs(bool scanmode) {
       m_pSettings->writeEntry(ScanNonCvs, scanmode);
    }
-   bool askForQuit() {
-      return m_pSettings->readBoolEntry(AskForQuit, true);
-   }
-   void setAskForQuit(bool ask) {
-      m_pSettings->writeEntry(AskForQuit, ask);
-   }
    QString cvsIgnoreFiles() {
       return m_pSettings->readEntry(CvsIgnoreFiles, defCvsIgnoreFiles);
    }
@@ -533,24 +528,39 @@ public:
    }
 
    bool getStdDlg() {
-     return m_pSettings->readBoolEntry(UseStandardDialogs, true);
+      return m_pSettings->readBoolEntry(UseStandardDialogs, true);
    }
    void setStdDlg(bool state) {
-     m_pSettings->writeEntry(UseStandardDialogs,state);
+      m_pSettings->writeEntry(UseStandardDialogs,state);
    }
    int getDateTimeOrder() {
-     return m_pSettings->readNumEntry(DateTimeOrder, QDateEdit().order());
+      return m_pSettings->readNumEntry(DateTimeOrder, QDateEdit().order());
    }
    void setDateTimeOrder( QDateEdit::Order order) {
-     m_pSettings->writeEntry(DateTimeOrder,order);
+      m_pSettings->writeEntry(DateTimeOrder,order);
    }
    QString getDateTimeFormat() {
-     return m_pSettings->readEntry(DateTimeFormat, "yyyy/MM/dd hh:mm:ss");
+      return m_pSettings->readEntry(DateTimeFormat, "yyyy/MM/dd hh:mm:ss");
    }
    void setDateTimeFormat( QString format) {
-     m_pSettings->writeEntry(DateTimeFormat,format);
+      m_pSettings->writeEntry(DateTimeFormat,format);
+   }
+   bool get0AsParent() {
+#ifdef Q_WS_WIN
+      return m_pSettings->readBoolEntry(Use0AsParent, false);
+#else
+      return m_pSettings->readBoolEntry(Use0AsParent, true);
+#endif
+   }
+   void set0AsParent(bool state) {
+      m_pSettings->writeEntry(Use0AsParent,state);
+   }
+   bool getTopLevelW() {
+      return m_pSettings->readBoolEntry(TopLevelWidget, true);
+   }
+   void setTopLevelW(bool state) {
+      m_pSettings->writeEntry(TopLevelWidget,state);
    }
-
    unsigned int historySizeComments() {
       return m_pSettings->readNumEntry(HistSizeComments, 20);
    }
@@ -779,38 +789,38 @@ public:
    }
    
    QString getFontGeneral() {
-     return m_pSettings->readEntry(FontGeneral, "");  //empty string means default font
+      return m_pSettings->readEntry(FontGeneral, "");  //empty string means default font
    }
    void setFontGeneral(const QString& font) {
       m_pSettings->writeEntry(FontGeneral, font);
    }
    QString getFontMessage() {
-     return m_pSettings->readEntry(FontMessage, "");  //empty string means default font
+      return m_pSettings->readEntry(FontMessage, "");  //empty string means default font
    }
    void setFontMessage(const QString& font) {
       m_pSettings->writeEntry(FontMessage, font);
    }
    QString getFontDiff() {
-     return m_pSettings->readEntry(FontDiff, "");  //empty string means default font
+      return m_pSettings->readEntry(FontDiff, "");  //empty string means default font
    }
    void setFontDiff(const QString& font) {
       m_pSettings->writeEntry(FontDiff, font);
    }
 
    QString getTextEncoder() {
-     return m_pSettings->readEntry(TextEncoder, TextCodec::DEFAULT_CODEC);  //we should use codec for locale
+      return m_pSettings->readEntry(TextEncoder, TextCodec::DEFAULT_CODEC);  //we should use codec for locale
    }
    void setTextEncoder(const QString& encoder) {
       m_pSettings->writeEntry(TextEncoder, encoder);
    }
    QString getTextDecoder() {
-     return m_pSettings->readEntry(TextDecoder, TextCodec::DEFAULT_CODEC);  //we should use codec for locale
+      return m_pSettings->readEntry(TextDecoder, TextCodec::DEFAULT_CODEC);  //we should use codec for locale
    }
    void setTextDecoder(const QString& decoder) {
       m_pSettings->writeEntry(TextDecoder, decoder);
    }
    
-protected:
+ protected:
    int geomX() {
       return m_pSettings->readNumEntry(GeomX, 50);
    }
@@ -836,23 +846,25 @@ protected:
       m_pSettings->writeEntry(GeomHeight, val);
    }
 
-protected:
+ protected:
 
    QSettings* m_pSettings;
 
-private:
+ private:
       
    void readProjectSettings( QString);
    void writeProjectSettings( QString);
    void removeProjectSettings( QString);
 
    void updateVersionOnRead(const QString&,const QString&);
-   void updateVersionOnWrite(const QString&,const QString&);
+   QString updateVersionOnWrite(const QString&,const QString&);
    void readProfiles(QStringList tmpList);
 
    void readExtApps();
    void writeExtApps();
 
+   Mapping::FileAppList extractMapping(const QStringList&);
+   QStringList joinMapping(const Mapping::FileAppList&);
    bool m_needUpdate;
 
 };
