@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** $Id: TagDialogImpl.cpp,v 1.21 2004/01/11 22:30:25 riemer Exp $
+** $Id: TagDialogImpl.cpp,v 1.26 2004/12/03 00:28:04 tilo Exp $
 **
 ** Copyright (C) 2001-2004 The LinCVS development team.
 **    Tilo Riemer <riemer@lincvs.org>
@@ -92,6 +92,7 @@
 #include <qstringlist.h>
 #include <qpushbutton.h>
 #include <qwhatsthis.h>
+#include <qtimer.h>
 
 #include "TagDialogImpl.h"
 #include "pixmapcache.h"
@@ -107,8 +108,10 @@
 
 TagDialogImpl::TagDialogImpl( QString module, QStringList * list, QString moduleName, 
 			      const QIconSet &whatsThisIconSet,
-			      QWidget * parent,  const char* name, bool, WFlags fl)
-  : TagDialog(parent, name, true, fl),
+			      QWidget * parent,  const char* name)
+  : TagDialog(parent, name, true, LookAndFeel::g_modalF),
+    m_parent(parent),
+    m_name(FetchButton->name()),
     m_module(module),
     m_pSelectedTagList(list),
     m_topModuleName(moduleName),
@@ -118,7 +121,8 @@ TagDialogImpl::TagDialogImpl( QString module, QStringList * list, QString module
     m_pOldFirstTagPixmap(NULL),
     m_pOldSecondTagPixmap(NULL),
     m_lastFirstTagLen(0),
-    m_lastSecondTagLen(0)
+    m_lastSecondTagLen(0),
+    m_running(false)
 {
 
   m_pWhatsThis->setIconSet(whatsThisIconSet);
@@ -201,40 +205,56 @@ void TagDialogImpl::readProjectNameList() {
 
 void TagDialogImpl::fetchClicked() {
 
-  if (m_fetchOverall ^= TRUE) {//overall mode
-    emit getProjectTags();
+  if (m_running ^= true) {//not running
+    FetchButton->setName("stop action");
+    FetchButton->setText(tr("Stop"));
+    if (m_fetchOverall ^= TRUE) {//overall mode
+      emit getProjectTags();
+    } else {
+      emit getSelectedTags();
+    }
   } else {
-    emit getSelectedTags();
+    QTimer::singleShot(0,m_parent,SLOT(stopCurAction()));
+    FetchButton->setName(m_name);
+    if (m_fetchOverall ^= TRUE) {//overall mode
+      FetchButton->setText( tr("Fetch selected"));
+    } else {
+      FetchButton->setText( tr("Fetch all"));
+    }
   }
 }
 
 void TagDialogImpl::tagListUpdated() {
 
-  m_firstTagListOnUpdate = TRUE;
-  m_secondTagListOnUpdate = TRUE;
-  m_firstTagListOnEdit = FALSE;
-  m_secondTagListOnEdit = FALSE;
-  m_pFirstTag->clear();
-  m_pSecondTag->clear();
-  m_pFirstTag->insertItem("T: HEAD");
-  m_pSecondTag->insertItem("T: HEAD");
-  if (m_fetchOverall) {
-    FetchButton->setText( tr("Fetch selected"));
-    readProjectNameList();
-    m_pFirstTag->insertStringList(m_ProjectTagList);
-    m_pSecondTag->insertStringList(m_ProjectTagList);
-  } else {
-    FetchButton->setText( tr("Fetch all"));
-    m_pFirstTag->insertStringList(*m_pSelectedTagList);
-    m_pSecondTag->insertStringList(*m_pSelectedTagList);
+  m_running = false;
+  if (!globalStopAction) {
+    m_firstTagListOnUpdate = TRUE;
+    m_secondTagListOnUpdate = TRUE;
+    m_firstTagListOnEdit = FALSE;
+    m_secondTagListOnEdit = FALSE;
+    m_pFirstTag->clear();
+    m_pSecondTag->clear();
+    m_pFirstTag->insertItem("T: HEAD");
+    m_pSecondTag->insertItem("T: HEAD");
+    FetchButton->setName(m_name);
+    if (m_fetchOverall) {
+      FetchButton->setText( tr("Fetch selected"));
+      readProjectNameList();
+      m_pFirstTag->insertStringList(m_ProjectTagList);
+      m_pSecondTag->insertStringList(m_ProjectTagList);
+    } else {
+      FetchButton->setText( tr("Fetch all"));
+      m_pFirstTag->insertStringList(*m_pSelectedTagList);
+      m_pSecondTag->insertStringList(*m_pSelectedTagList);
+    }
+    setPixmaps(m_pFirstTag);
+    m_oldFirstTagText = m_pFirstTag->currentText();
+    m_firstTagListOnUpdate = FALSE;
+    setPixmaps(m_pSecondTag);
+    m_oldSecondTagText = m_pFirstTag->currentText();
+    m_secondTagListOnUpdate = FALSE;
+    m_pFirstTag->lineEdit()->selectAll();
   }
-  setPixmaps(m_pFirstTag);
-  m_oldFirstTagText = m_pFirstTag->currentText();
-  m_firstTagListOnUpdate = FALSE;
-  setPixmaps(m_pSecondTag);
-  m_oldSecondTagText = m_pFirstTag->currentText();
-  m_secondTagListOnUpdate = FALSE;
-  m_pFirstTag->lineEdit()->selectAll();
 }
 
 void TagDialogImpl::setPixmaps(QComboBox * box) {
