@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** $Id: colortab.h,v 1.10 2004/03/05 00:18:57 hemer Exp $
+** $Id: colortab.h,v 1.11 2004/12/17 19:58:43 frank Exp $
 **
 ** Copyright (C) 2001-2004 The LinCVS development team.
 **    Tilo Riemer <riemer@lincvs.org>
@@ -117,7 +117,7 @@ public :
         virtual void paintLabel( QPainter *, const QRect &,QTab *, bool ) const;
 
         ColorTab * colorTab( int i ) 
-                { return (ColorTab *)QTabBar::tab( i ); }
+                { return (ColorTab *)QTabBar::tabAt( i ); }
 
 };
 
