@@ -1,17 +1,12 @@
 /****************************************************************************
 **
-** $Id: globals.h,v 1.109 2004/04/25 23:19:11 riemer Exp $
+** $Id: globals.h,v 1.124.2.2 2005/01/16 14:29:35 tilo Exp $
 **
-** Copyright (C) 1999-2004 The LinCVS development team.
-**    Tilo Riemer <riemer@lincvs.org>
-**    Falk Brettschneider <gigafalk@yahoo.com>
-**    Frank Hemer <frank@hemer.org>
-**    Wim Delvaux <wim.delvaux@chello.be>
-**    Jose Hernandez <joseh@tesco.net>
-**    Helmut Koll <HelmutKoll@web.de>
-**    Tom Mishima <tmishima@mail.at-m.or.jp>
-**    Joerg Preiss <auba@auba.de>
-**    Sven Trogisch <trogisch@iapp.de>
+** Copyright (C) 1999-2004 Tilo Riemer <riemer@lincvs.org>,
+**                         Frank Hemer <frank@hemer.org>,
+**                         Jose Hernandez <joseh@tesco.net>,
+**                         Tom Mishima <tmishima@mail.at-m.or.jp>,
+**                         Joerg Preiss <auba@auba.de>
 **
 **
 **----------------------------------------------------------------------------
@@ -101,20 +96,11 @@
 
 #include "profile.h"
 #include "ProjectSettings.h"
-#include "directory.h"
+#include "DirBase.h"
 #include "DirConnector.h"
 
 //----------------------------------------------------------------------------
 
-#ifdef Q_WS_WIN
-#ifdef USE_DEBUG_CONSOLE
-#include <iostream>
-#define qDebug(x) std::cout << QString(x).latin1() << "\n";//use qDebug on console;-)
-#endif
-#endif
-
-//----------------------------------------------------------------------------
-
 #ifdef DEFINE_GLOBALS
   #define EXTERN
   //event monitoring
@@ -174,52 +160,63 @@ class CTextEncoder;
 
 //step by step reorganizing of global variables using namespaces
 namespace CvsOptions {
-  /**
-  GZip compression level. 0 means no compression. 1 is the minimal
-  compression level, 9 is the maximal level.
-  */
-  EXTERN unsigned int g_compression;
+   /**
+      GZip compression level. 0 means no compression. 1 is the minimal
+      compression level, 9 is the maximal level.
+   */
+   EXTERN unsigned int g_compression;
 
-  /**
-  Returns an empty string if compression is 0 or -z[1..9].
-  */
-  extern const QString cmprStr();
+   /**
+      Returns an empty string if compression is 0 or -z[1..9].
+   */
+   extern const QString cmprStr();
+   
+   /**
+      Prune (remove) directories that are empty after being updated etc.
+   */
+   EXTERN bool g_bPruneDirs;
+   
+   /**
+      Bring over new directories if run update and friends.
+   */
+   EXTERN bool g_bBringOverNewDirs;
+   
+   /**
+      Show virtual dirs (query update all) only in filetab
+   */
+   EXTERN bool g_bShowVirtualInFiletab;
+   
+   /**
+      Per-line diff precision
+   */
+   EXTERN int g_precision;
+   
+   /**
+      Unified diff output
+   */
+   EXTERN bool g_bUnifiedDiffOutput;
+   
+   /**
+      quiet CVS commands
+   */
+   EXTERN bool g_bQuietCvs;
+   
+   /**
+      history period
+   */
+   EXTERN int g_historyPeriod;
+}
 
-  /**
-  Prune (remove) directories that are empty after being updated etc.
-  */
-  EXTERN bool g_bPruneDirs;
-
-  /**
-  Bring over new directories if run update and friends.
-  */
-  EXTERN bool g_bBringOverNewDirs;
-
-  /**
-  Show virtual dirs (query update all) only in filetab
-  */
-  EXTERN bool g_bShowVirtualInFiletab;
-
-  /**
-  Per-line diff precision
-  */
-  EXTERN int g_precision;
-
-  /**
-  Unified diff output
-  */
-  EXTERN bool g_bUnifiedDiffOutput;
-
-  /**
-  quiet CVS commands
-  */
-  EXTERN bool g_bQuietCvs;
-
-  /**
-  history period
-  */
-  EXTERN int g_historyPeriod;
-};
+namespace AutoUpdate {
+   enum Level {
+      OFF = 0,
+      QUERY = 1,
+      STATUS = 2,
+      UPDATE = 3,
+      QUERYALL = 4,
+      UPDATEALL = 5
+   };
+}
 
 namespace ExtApps {
    
@@ -227,35 +224,35 @@ namespace ExtApps {
       QString path;     //path (abs. or rel. + app file name
       QString options;
    };
-
+   
    EXTERN App g_localShell;
    EXTERN App g_localBrowser;
    EXTERN App g_remoteBrowser;
    EXTERN App g_cvsRsh;
    EXTERN App g_diffProg;
-};
+}
 
 namespace DirWatch {
-  EXTERN bool b_useDirWatch;
-  EXTERN bool b_isActive;
-};
+   EXTERN bool b_useDirWatch;
+   EXTERN bool b_isActive;
+}
 
 namespace Polling {
-  enum Level {
-    NONE = 0,
-    CURRENT = 1,
-    ALLDIRS = 2,
-    ALLFILES = 3,
-    ALLPROJECTS = 4
-  };
-  EXTERN int checkStatusLevel;
-};
+   enum Level {
+      NONE = 0,
+      CURRENT = 1,
+      ALLDIRS = 2,
+      ALLFILES = 3,
+      ALLPROJECTS = 4
+   };
+   EXTERN int checkStatusLevel;
+}
 
 namespace LinCVSEvents {
-  enum Type {
-    T_WINNT_DIRWATCH = 65432
-  };
-};
+   enum Type {
+      T_WINNT_DIRWATCH = 65432
+   };
+}
 
 namespace HighlightProperties {
    //we could give the user the possibility to change the font instead of 
@@ -265,12 +262,12 @@ namespace HighlightProperties {
       FS_BOLD   = 1,
       FS_ITALIC = 2
    };
-
+   
    struct Properties {
       FontStyle style;
       QColor    color;
    };
-
+   
    //use syntax highlighting?
    EXTERN bool g_bUseSyntaxHighlighting;
    
@@ -283,64 +280,90 @@ namespace HighlightProperties {
    EXTERN Properties g_updateAdded;             //added file(s)
    EXTERN Properties g_updateRemoved;           //removed file(s)
    EXTERN Properties g_updateRemovedByOther;    //removed file(s) by another one
-
+   
    //diff to console
    EXTERN Properties g_diffOld;     //lines starting with <
    EXTERN Properties g_diffNew;     //lines starting with >
-};
+}
 
 namespace Font {
-  //we use the string representations of fonts. if empty --> default font
-  EXTERN QString g_general;
-  EXTERN QString g_message;
-  EXTERN QString g_diff; 
-
-  //never we write this value to the config file, we must only save the 
-  //default font set by qtconfig at runtime
-  EXTERN QString g_default; 
-};
+   //we use the string representations of fonts. if empty --> default font
+   EXTERN QString g_general;
+   EXTERN QString g_message;
+   EXTERN QString g_diff; 
+   
+   //never we write this value to the config file, we must only save the 
+   //default font set by qtconfig at runtime
+   EXTERN QString g_default; 
+}
 
 namespace LookAndFeel {
-  //use std-dialogs if true
-  EXTERN bool g_stdDlg;
-  EXTERN QDateEdit::Order g_dateTimeOrder;
-  EXTERN QString g_dateTimeFormat;
-};
+   //use std-dialogs if true
+   EXTERN bool g_stdDlg;
+   EXTERN QDateEdit::Order g_dateTimeOrder;
+   EXTERN QString g_dateTimeFormat;
+   EXTERN bool g_b0AsParent;
+   EXTERN bool g_bTopLevel;
+   EXTERN Qt::WFlags g_nonModalF;
+   EXTERN Qt::WFlags g_modalF;
+}
 
 namespace I18n {
-  EXTERN CMetaTextDecoder* g_pTextDecoder;
-  EXTERN QString g_nameOfDecoder;  //name of decoder used for all non file specific stuff
-
-  EXTERN CTextEncoder* g_pTextEncoder;
-  EXTERN QString g_nameOfEncoder;  //name of Encoder
-
-  extern void init();
-  extern void destroy();
-};
+   EXTERN CMetaTextDecoder* g_pTextDecoder;
+   EXTERN QString g_nameOfDecoder;  //name of decoder used for all non file specific stuff
+   
+   EXTERN CTextEncoder* g_pTextEncoder;
+   EXTERN QString g_nameOfEncoder;  //name of Encoder
+   
+   extern void init();
+   extern void destroy();
+}
 
 namespace Debug {
-  enum LogLevel {
-    LL_LIKE_A_FISH = 0,              //little or nothing
-    LL_THE_OLD_MAN_AND_THE_SEA = 1,  //almost nothing
-    LL_INFO = 2,                     //log runtime infos
-    LL_DEBUG = 3,                    //log infos and debug stuff
-    LL_GOSSIP_MONGER = 4             //log all
-  };
-
-  EXTERN bool g_bDebug;
-  EXTERN LogLevel g_logLevel;
-  EXTERN CLinCVSLog* g_pLog;
-};
+   enum LogLevel {
+      LL_LIKE_A_FISH = 0,              //little or nothing
+      LL_THE_OLD_MAN_AND_THE_SEA = 1,  //almost nothing
+      LL_INFO = 2,                     //log runtime infos
+      LL_DEBUG = 3,                    //log infos and debug stuff
+      LL_GOSSIP_MONGER = 4             //log all
+   };
+   
+   EXTERN bool g_bDebug;
+   EXTERN LogLevel g_logLevel;
+   EXTERN CLinCVSLog* g_pLog;
+}
 
 namespace HistorySize {
-  EXTERN unsigned int g_profiles;
-  EXTERN unsigned int g_workdirs;
-  EXTERN int g_commitinfo;
-};
+   EXTERN unsigned int g_profiles;
+   EXTERN unsigned int g_workdirs;
+   EXTERN int g_commitinfo;
+}
 
 namespace SizeProperties {
-  EXTERN QString g_fileHeader;
-};
+   EXTERN QString g_fileHeader;
+}
+
+namespace Dialog {
+   EXTERN bool g_showWarning;
+}
+
+namespace Misc {
+#ifdef Q_WS_X11
+   EXTERN QString g_rcPath;  // additional rcpath
+#endif
+}
+
+namespace Mapping {
+   struct FileAppItem {
+      QString wildcard;
+      QString app;
+      QString params;
+      bool isRegExp;
+   };
+   typedef QValueList<FileAppItem> FileAppList;
+   EXTERN FileAppList openFileAppList;
+   EXTERN FileAppList viewFileAppList;
+}
 
 //--- cfg values -------------------------------------------------------------
 
@@ -360,8 +383,6 @@ EXTERN QString CVSIGNOREFILES;
 EXTERN QString DIRPOPUPMENU;
 EXTERN QString FILEPOPUPMENU;
 EXTERN QString KEYBOARDSHORTCUTS;
-EXTERN QStringList OPENFILELIST;
-EXTERN QStringList VIEWFILELIST;
 
 EXTERN QStringList MODULEHISTORYLIST;
 EXTERN QStringList WORKDIRHISTORYLIST;
@@ -412,7 +433,6 @@ EXTERN QString  envSSH_AUTH_SOCK;
 EXTERN QColor   SELECTION_COLOR_OF_LOGDLG[2];
 
 EXTERN bool     bUSEEXTERNALDIFFFORSIDEBYSIDE;
-EXTERN bool     bAskForQuit;
 EXTERN bool     bUseSmallIcons;
 EXTERN bool     bStartedInDir;
 EXTERN bool     bRWPermission;
@@ -439,12 +459,7 @@ EXTERN QValueList<CLincvsProfile> cvsProfileContentList;
 //--- functions --------------------------------------------------------------
 
 extern void    initGlobals();
-
 extern void    determineTimeZoneDiff();
-extern QDateTime getAsUTC( QDateTime&, bool);
-extern QDateTime getAsLocal( QDateTime&, bool);
-extern QDateTime convertTimeZone( QDateTime&, bool, bool);
-extern bool    hasDSTBug( QString*);
 extern bool    isInCvsPass(QString cvsRoot);
 extern bool    writeToCvsPassFile(const QString& cvsRoot, const QString& pwd);
 extern bool    removeFromCvsPassFile( QString cvsRoot);
@@ -453,19 +468,21 @@ extern bool    removeFromCvsPassFile( QString cvsRoot);
 /*                              QString& host, QString& rootDir); */
 
 extern int     analyzeCVSROOT( QString& method,
-			       QString& user,
-			       QString& passwd,
-			       QString& host,
-			       int& port,
-			       QString& path);
+      QString& user,
+      QString& passwd,
+      QString& host,
+      int& port,
+      QString& path);
 
 extern int     extractCVSROOT( QString rootline,
-			       QString& method,
-			       QString& user,
-			       QString& passwd,
-			       QString& host,
-			       int& port,
-			       QString& path);
+      QString& method,
+      QString& user,
+      QString& passwd,
+      QString& host,
+      int& port,
+      QString& path);
+
+extern int     validateCVSROOT( QString rootline);
 
 extern void    removeDoubleSlashes(QString& s);
 
@@ -509,6 +526,16 @@ extern void cutList(QStringList* pList, int allowedSize);
 //masque filenames containing whitespaces for use with InteractiveCmdThread
 extern QString masqWs(const QString &str);
 extern QString umasqWs(QString str);
+
+//validation of passed command line options
+extern QString validateOptions(const QString options);
+
+//open URL[s] with the remote browser
+extern void openUrlWithRemoteBrowser(const QString url);
+extern void openUrlsWithRemoteBrowser(const QStringList urlList);
+
+//mapping
+extern Mapping::FileAppItem getMatchForWildcard(const QStringList& nameList, const Mapping::FileAppList& appList);
 extern bool masqedFilenamesForPlaceholders(QString& params, const QStringList& nameList);
 
 //wrappers for platform specific funktions
@@ -529,9 +556,9 @@ extern bool initMonitoring();
 extern DirConnector* getDirConnector();
 extern bool hasDirWatch();
 extern void releaseMonitoring();
-extern bool addMonitoredDir(Directory*);
-extern void releaseMonitoredDir(Directory*);
-extern Directory* checkMonitoredEvent(QString&,bool&);
+extern bool addMonitoredDir(DirBase*);
+extern void releaseMonitoredDir(DirBase*);
+extern DirBase* checkMonitoredEvent(QString&,bool&);
 extern void suspendDirWatch();
 extern void resumeDirWatch();
 extern void lockDirWatch();
